% Supplementary Matlab Code for
% "Gunay, Edgerton, Li, Sangrey, Prinz and Jaeger (2008).
% Database analysis of simulated and recorded electrophysiological datasets
% with PANDORA's Toolbox

% Examples in this file require the supplementary Matlab data file:
% load an intracellular trace of 160 ms
load('supp_mat_1_dat.mat')

% create trace object with 10 kHz sample rate and mV units
if exist('filtfilt', 'file') == 2
    % using the signal processing toolbox
    a_trace = trace(test_data, 1e-4, 1e-3, 'test trace');
    a_spikes = spikes(a_trace);
else
    % using the signal processing toolbox
    a_trace = trace(test_data, 1e-4, 1e-3, 'test trace', ...
                    struct('spike_finder', 2, 'threshold', -85));
    a_spikes = spikes(a_trace);
end

% disable warnings
warning off backtrace
warning off calcInitVm:info

% extract spike characteristics
[results period_spikes a_spikes_db spikes_stats_db spikes_hists_dbs]= ...
  analyzeSpikesInPeriod(a_trace, a_spikes, periodWhole(a_trace), '');

% display info about spikes DB extracted from data
a_spikes_db %#ok<NOPTS>

% plot all spikes annottaed on the trace (takes a long time for the
% 10-second trace!
plot(a_spikes_db);

% display the statistics
displayRows(spikes_stats_db)

% plot some histograms
plot(histogram(a_spikes_db, 'InitVm')); % threshold voltage
plot(histogram(a_spikes_db, 'MaxAHP')); % AHP magnitude
plot(histogram(a_spikes_db, 'MinVm')); % minimum of AHP voltage

% make the example plot in the paper
plotFigure(plot_abstract(a_spikes_db, 'annotated spike characteristics', ...
           struct('fixedSize', [2 2], 'axisLimits', [1450 1555 -100 -60], ...
                  'quiet', 1)))
